<?php

if ( ! defined( 'ABSPATH' ) ) {	exit; }

class OSMaps_frontend{
    public $OS = '';
    public $db_options = [];
    
            
    function __construct( $OSM, $osmaps_db_options ) {        
        $this->OS = $OSM;
        $this->OS->markerURL = $this->OS->dirURL  . 'public/marker-green.png';
        $this->OS->urlDirections = 'https://www.openstreetmap.org/directions?from=';
        $this->OS->olJsURL = $this->OS->dirURL . 'public/ol.min.js';
        
         $this->db_options = $osmaps_db_options;
        
        add_action( 'wp_enqueue_scripts', [ $this, 'load_external_resources' ] );

        add_shortcode( $this->OS->shortcode, [ $this, 'shortcodes_OSMaps_exec' ] );
    }
    
    
    function load_external_resources(){
        $deps = [];                     // $prm = get_permalink(); exit($prm);
       
        wp_register_style( 'olmincss', $this->OS->dirURL . 'public/ol.min.css', $deps, null );
        wp_enqueue_style( 'olmincss' );
        
        wp_register_style( 'popupmincss', $this->OS->dirURL . 'public/popup.min.css', $deps, null );
        wp_enqueue_style( 'popupmincss' );

        wp_add_inline_style( 'popupmincss', $this->customStyle($this->db_options['mapDefault']) );
        
        wp_register_script( 'olminjs', $this->OS->dirURL . 'public/ol.min.js', $deps, null, FALSE );
        wp_enqueue_script('olminjs');                                                                 
 
    }
    
    

    function shortcodes_OSMaps_exec( $atts ){
        
        extract( shortcode_atts([ 'id' => '' ], $atts ));
        
        /*  $id vuoto mantiene la compatibilità alle versioni precedenti    */
        if( $id === '') { $db_options = $this->db_options[ 'mapDefault' ]; } else { $db_options = $this->db_options[ $id ]; }
        
        if ( isset( $db_options['mapopup'] )){
            $db_options['mapopup'] = str_replace( "\r\n", "<br>", $db_options['mapopup'] );
            $db_options['mapopup'] = str_replace( ["\n", "\t", "\r"], "&nbsp", $db_options['mapopup'] );
            $db_options['mapopup'] = str_replace( "'", "&#39;", $db_options['mapopup'] );
            $db_options['mapopup'] = str_replace( "&lt;", "<", $db_options['mapopup'] ); 
            $db_options['mapopup'] = str_replace( "&gt;", ">", $db_options['mapopup'] );
        }
        
        
        switch ( $db_options['mptype'] ){
            case 1:
                $a = $this->HTMLsimple($db_options);
                break;
            case 2:
                $a = $this->HTMLmarker($db_options);
                break;
            case 3:
                $a = $this->HTMLpopup($db_options);
                break;
            case 5:
                $a = $this->HTMLmarker_popup2($db_options);
                break;

            default:
                $a = sprintf( __( 'OSMaps error #1: wrong select! %s does not exist.', 'osmapsWP' ), $db_options['mptype'] );
                break;
        }

        return $a;        
    }
    
    /**
     * Case: 1 
     * look /plugins/OSMaps/public/expanded/HTMLsimple.html     for expanded code 
     * @return string
     */
    function HTMLsimple($db_options) {
        
        ($db_options['noWheel'] === 'checked') ? $wheel = "interactions: ol.interaction.defaults( {mouseWheelZoom:false} )," : $wheel = '';
        
        $html = <<<HTM
<div id="osmaps_map" class="osmapsMap"></div>
<script>
var map = new ol.Map({{$wheel}layers: [new ol.layer.Tile({source: new ol.source.OSM()})],target: 'osmaps_map',view: new ol.View({ center: ol.proj.fromLonLat([{$db_options['longitude']}, {$db_options['latitude']}]), zoom: {$db_options['zoom']}})});
</script>
HTM;
        return $html;        
    }
    
    
    /**
     * Case: 2
     * look /plugins/OSMaps/public/expanded/HTMLmarker.html     for expanded code
     * @return string
     */
    function HTMLmarker($db_options) {
        ($db_options['noWheel'] === 'checked') ? $wheel = "interactions: ol.interaction.defaults( {mouseWheelZoom:false} )," : $wheel = '';
        
        $html = <<<HTM
<div id="osmaps_map" class="osmapsMap"></div>
<script>
var city = new ol.Feature({geometry: new ol.geom.Point(ol.proj.fromLonLat([{$db_options['longitude']}, {$db_options['latitude']}]))}); city.setStyle(new ol.style.Style({image: new ol.style.Icon(({src: '{$this->OS->markerURL}', anchor: [0.5, 1]}))}));
var vectorSource = new ol.source.Vector({features: [city]});
var vectorLayer = new ol.layer.Vector({source: vectorSource});       
var map = new ol.Map({{$wheel}layers: [new ol.layer.Tile({source: new ol.source.OSM()}),vectorLayer],target: 'osmaps_map', view: new ol.View({center: ol.proj.fromLonLat([{$db_options['longitude']}, {$db_options['latitude']}]), zoom: {$db_options['zoom']}})});
</script>
HTM;
        return $html;
    }
    
    
    
    function HTMLpopup_sub($db_options) {
        $directions_icon_url = $this->OS->dirURL . 'public/Directions_image1.png';
        
        $html = <<<HEO
<div id="os_map" class="osmapsMap"></div>               
<div id="popup" class="ol-popup">
    <a href="#" id="popup-closer" class="ol-popup-closer"></a>
    <div class="ol-popup-direc">
    <a id="popup_href_directions" target="_blank"><img alt="Directions Icon" src="{$directions_icon_url}" title="Directions"></a>
    </div>
    <div id="popup_content" class="ol-popup-content">{$db_options['mapopup']}</div>
</div>
HEO;
        return $html;
    } 
    
    
    /**
     * Case: 3
     * look /plugins/OSMaps/public/expanded/HTMLpopup.html     for expanded code
     * @return string
     */
    function HTMLpopup($db_options) {
        
        ($db_options['noWheel'] === 'checked') ? $wheel = "interactions: ol.interaction.defaults( {mouseWheelZoom:false} )," : $wheel = '';
        
        $html = $this->HTMLpopup_sub($db_options);
        
        $js = <<<JS
<script>
var markerLon = {$db_options['longitude']}, markerLat = {$db_options['latitude']}, myZoom = {$db_options['zoom']};
var centerLon = markerLon, centerLat = markerLat;
var container = document.getElementById('popup');
var closer = document.getElementById('popup-closer');
var Lat2Direc, Lon2Direc;
(Number.isInteger(markerLat)) ? Lat2Direc = markerLat.toString()+'.00' : Lat2Direc = markerLat.toString();
(Number.isInteger(markerLon)) ? Lon2Direc = markerLon.toString()+'.00' : Lon2Direc = markerLon.toString();        
popup_href_directions.href = '{$this->OS->urlDirections}' + Lat2Direc + ',' + Lon2Direc;
var overlay = new ol.Overlay({ element: container, autoPan: true, position: ol.proj.fromLonLat([markerLon, markerLat]),offset: [-80,-30],autoPanAnimation: { duration: 250}});
closer.onclick = function(){overlay.setPosition(undefined); closer.blur(); return false;};
var map = new ol.Map({{$wheel}layers: [new ol.layer.Tile({ source: new ol.source.OSM()})],overlays: [overlay], target: 'os_map', view: new ol.View({center: ol.proj.fromLonLat([centerLon, centerLat]), zoom: myZoom})});
map.on('singleclick', function () {overlay.setPosition(ol.proj.fromLonLat([markerLon, markerLat]));});
</script>
JS;
        $html .= $js;
        return $html;        
    }
    
    
    /**
     * Case 5:
     * look /plugins/OSMaps/public/expanded/HTMLmarker_popup2.html     for expanded code
     * @return string
     */
    function HTMLmarker_popup2($db_options) {
        
        ($db_options['noWheel'] === 'checked') ? $wheel = "interactions: ol.interaction.defaults( {mouseWheelZoom:false} )," : $wheel = '';
                
        $html = $this->HTMLpopup_sub($db_options);
        
        $js = <<<JS
<script>
var markerLon = {$db_options['longitude']}, markerLat = {$db_options['latitude']}, myZoom = {$db_options['zoom']};
var centerLon = markerLon, centerLat = markerLat;
var container = document.getElementById('popup');
var closer = document.getElementById('popup-closer');
var Lat2Direc, Lon2Direc;
(Number.isInteger(markerLat)) ? Lat2Direc = markerLat.toString()+'.00' : Lat2Direc = markerLat.toString();
(Number.isInteger(markerLon)) ? Lon2Direc = markerLon.toString()+'.00' : Lon2Direc = markerLon.toString();        
popup_href_directions.href = '{$this->OS->urlDirections}' + Lat2Direc + ',' + Lon2Direc;
var overlay = new ol.Overlay({ element: container, autoPan: true, position: ol.proj.fromLonLat([markerLon, markerLat]), offset: [-80,-30], autoPanAnimation: { duration: 250}});
closer.onclick = function(){overlay.setPosition(undefined);closer.blur();return false;};
var city = new ol.Feature({geometry: new ol.geom.Point(ol.proj.fromLonLat([markerLon, markerLat]))});
city.setStyle(new ol.style.Style({image: new ol.style.Icon(({src: '{$this->OS->markerURL}',anchor: [0.5, 1]}))}));
var vectorSource = new ol.source.Vector({features: [city]});
var vectorLayer = new ol.layer.Vector({source: vectorSource});
var map = new ol.Map({{$wheel}layers: [new ol.layer.Tile({source: new ol.source.OSM()}),vectorLayer],overlays: [overlay],target: 'os_map',view: new ol.View({center: ol.proj.fromLonLat([centerLon,centerLat]),zoom: myZoom})});
map.on('singleclick', function () {overlay.setPosition(ol.proj.fromLonLat([markerLon, markerLat]));});
</script>
JS;
        $html .= $js;
        return $html;
    }
    
    
    function customStyle($db_options){
    /*  'px' is already present in the options of database.  It is necessary to add only ';'    */
        ( $db_options['maxwtd'] != '' ) ?  ( $wdt = 'max-width:' . $db_options['maxwtd'] . '!important;' ) : $wdt = '' ;

        $personalStyle = sprintf( ".osmapsMap{height: %s; %s}", $db_options['height'], $wdt );

        return $personalStyle;
    }
    
    
}
